==> openshift-model-operator-5.4.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodePortStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NodePortStrategyBuilder extends io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluentImpl<io.fabric8.openshift.api.model.operator.v1.NodePortStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.NodePortStrategy,io.fabric8.openshift.api.model.operator.v1.NodePortStrategyBuilder> {

    io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public NodePortStrategyBuilder() {
        this(true);
    }

    public NodePortStrategyBuilder(java.lang.Boolean validationEnabled) {
        this(new NodePortStrategy(), validationEnabled);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent) {
        this(fluent, true);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new NodePortStrategy(), validationEnabled);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance) {
        this(fluent, instance, true);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        this.validationEnabled = validationEnabled; 
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance) {
        this(instance,true);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.openshift.api.model.operator.v1.NodePortStrategy build() {
        NodePortStrategy buildable = new NodePortStrategy();
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NodePortStrategyBuilder that = (NodePortStrategyBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-operator-5.7.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodePortStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NodePortStrategyBuilder extends io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluentImpl<io.fabric8.openshift.api.model.operator.v1.NodePortStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.NodePortStrategy,io.fabric8.openshift.api.model.operator.v1.NodePortStrategyBuilder> {

    io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public NodePortStrategyBuilder() {
        this(true);
    }

    public NodePortStrategyBuilder(java.lang.Boolean validationEnabled) {
        this(new NodePortStrategy(), validationEnabled);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent) {
        this(fluent, true);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new NodePortStrategy(), validationEnabled);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance) {
        this(fluent, instance, true);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withProtocol(instance.getProtocol()); 
        this.validationEnabled = validationEnabled; 
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance) {
        this(instance,true);
    }

    public NodePortStrategyBuilder(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withProtocol(instance.getProtocol()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.openshift.api.model.operator.v1.NodePortStrategy build() {
        NodePortStrategy buildable = new NodePortStrategy(fluent.getProtocol());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NodePortStrategyBuilder that = (NodePortStrategyBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
